@@ -18,6 +18,7 @@ from django_msms_admin.admin import DjangoSubclassAdmin
 from django_tabbed_changeform_admin.admin import DjangoTabbedChangeformAdmin
 from django_force_disable_permissions_admin.admin import DjagnoForceDisablePermissionsAdminMixin
 from django_toggle_switch_widget.widgets import DjangoToggleSwitchWidget
+from django_gazing_select_widget.widgets import DjangoGazingSelectWidget
 from django_mptt_simple_listfilters.filters import ListFilterIgnoreLeafNodes
 from .settings import CURRENT_SIET_ID_SESSION_KEY
 from .models import Template
@@ -41,6 +42,8 @@ from .models import Article
 from .models import ArticleContentImage
 from .models import ArticleListWidget
 from .models import ArticleDetailWidget
+from .models import CardsWidget
+from .models import CardsItem
 
 
 class TemplateSlotInline(DjangoReadEditSwitchAdmin, admin.TabularInline):
@@ -196,8 +199,38 @@ class SiteAdmin(
             request.session[CURRENT_SIET_ID_SESSION_KEY] = object_id
         return super().changeform_view(request, object_id, form_url, extra_context)
 
+def get_all_template_slots():
+    slots = [
+        ("", "-"*10),
+    ]
+    for slot in TemplateSlot.objects.order_by("template", "order").all():
+        slots.append((slot.pk, slot.template.name + "." + slot.name))
+    return slots
+
+def get_choices_related():
+    choices_related = {}
+    for slot in TemplateSlot.objects.order_by("template", "order").all():
+        choices_related[slot.pk] = [str(slot.template.pk)]
+    return choices_related
+
+class PageWidgetForm(ModelForm):
+    class Meta:
+        model = PageWidget
+        exclude = []
+        widgets = {
+            "slot": DjangoGazingSelectWidget(
+                gazing_field_name="template",
+                this_field_name="slot",
+                choices_related=get_choices_related,
+                gazing_related=False,
+                choices=get_all_template_slots,
+                )
+        }
+
 class PageWidgetInline(DjangoReadEditSwitchAdmin, admin.TabularInline):
+    form = PageWidgetForm
     model = PageWidget
+    extra = 0
     classes = ["tab-page-widgets"]
 
 class PageAdmin(
@@ -507,6 +540,27 @@ class ArticleDetailWidgetAdmin(DjangoSubclassAdmin, WidgetAdminBase, admin.Model
         tabs.insert(1, (_("Article Detail Settings"), ["tab-article-detail-settings"]))
         return tabs
 
+class CardsItemInline(admin.TabularInline):
+    model = CardsItem
+    extra = 0
+    classes = ["tab-cards-items"]
+
+class CardsWidgetAdmin(DjangoSubclassAdmin, WidgetAdminBase, admin.ModelAdmin):
+    inlines = [
+        WidgetLinkInline,
+        CardsItemInline
+    ]
+    fieldsets = WidgetAdmin.fieldsets + [
+        (None, {
+            "fields": ["card_width", "card_height", "image_width", "image_height", "title_height"],
+            "classes": ["tab-cards-widget-basic-settings"]
+        })
+    ]
+    def get_tabs(self, request, object_id, form_url, extra_context):
+        tabs = super().get_tabs(request, object_id, form_url, extra_context)
+        tabs.insert(1, (_("Cards Widget Settings"), ["tab-cards-widget-basic-settings", "tab-cards-items"]))
+        return tabs
+
 admin.site.register(Site, SiteAdmin)
 admin.site.register(Page, PageAdmin)
 admin.site.register(Article, ArticleAdmin)
@@ -518,6 +572,7 @@ admin.site.register(StaticListWidget, StaticListWidgetAdmin)
 admin.site.register(TopbarWidget, TopbarWidgetAdmin)
 admin.site.register(ArticleListWidget, ArticleListWidgetAdmin)
 admin.site.register(ArticleDetailWidget, ArticleDetailWidgetAdmin)
+admin.site.register(CardsWidget, CardsWidgetAdmin)
 
 admin.site.register(Template, TemplateAdmin)
 admin.site.register(Theme, ThemeAdmin)
