@@ -369,7 +369,7 @@ class PageWidget(models.Model):
     page = models.ForeignKey(Page, on_delete=models.CASCADE, related_name="widget_bindings", verbose_name=_("Page"))
     slot = models.ForeignKey(TemplateSlot, on_delete=models.SET_NULL, null=True, blank=True, related_name="+", verbose_name=_("Slot"))
     order = models.IntegerField(default=0, verbose_name=_("Order"))
-    widget = models.ForeignKey("Widget", on_delete=models.CASCADE, related_name="+", verbose_name=_("Widget"))
+    widget = models.ForeignKey("Widget", on_delete=models.CASCADE, limit_choices_to=limit_choices_to_selected_site, related_name="+", verbose_name=_("Widget"))
 
     class Meta:
         verbose_name = _("Page Widget Binding")
@@ -494,6 +494,9 @@ class WidgetLink(models.Model):
 class StaticHtmlWidget(Widget):
     html = models.TextField(null=True, blank=True, verbose_name=_("HTML Code"))
 
+    msms_category = _("Django Power Cms Default Widgets")
+    msms_priority = 2000
+
     class Meta:
         verbose_name = _("Static HTML Widget")
         verbose_name_plural = _("Static HTML Widgets")
@@ -514,6 +517,9 @@ class CarouselWidget(Widget):
         "bootstrap/js/bootstrap.min.js",
     ]
 
+    msms_category = _("Django Power Cms Default Widgets")
+    msms_priority = 4000
+
     class Meta:
         verbose_name = _("Carousel Widget")
         verbose_name_plural = _("Carousel Widgets")
@@ -545,6 +551,9 @@ class StaticListWidget(Widget):
     max_display_count = models.IntegerField(null=True, blank=True, verbose_name=_("Max Display Count"))
     empty_display_message = models.TextField(null=True, blank=True, verbose_name=_("Empty Display Message"))
 
+    msms_category = _("Django Power Cms Default Widgets")
+    msms_priority = 3000
+
     class Meta:
         verbose_name = _("Static List Widget")
         verbose_name_plural = _("Static List Widgets")
@@ -598,6 +607,9 @@ class TopbarWidget(Widget):
         return get_url(self.change_password_link_raw)
     change_password_link.short_description = _("Change Password Link")
 
+    msms_category = _("Django Power Cms Default Widgets")
+    msms_priority = 1000
+
     class Meta:
         verbose_name = _("Topbar Widget")
         verbose_name_plural = _("Topbar Widgets")
@@ -764,6 +776,9 @@ class ArticleListWidget(Widget):
     max_display_count = models.IntegerField(default=10, verbose_name=_("Max Display Count"))
     empty_display_message = models.TextField(null=True, blank=True, verbose_name=_("Empty Display Message"))
 
+    msms_category = _("Django Power Cms Default Widgets")
+    msms_priority = 5000
+
     class Meta:
         verbose_name = _("Article List Widget")
         verbose_name_plural = _("Article List Widgets")
@@ -788,6 +803,9 @@ class ArticleDetailWidget(Widget):
     show_author = models.BooleanField(default=False, verbose_name=_("Show Author"))
     show_prev_and_next_links = models.BooleanField(default=False, verbose_name=_("Show Prev&Next Links"))
 
+    msms_category = _("Django Power Cms Default Widgets")
+    msms_priority = 6000
+
     class Meta:
         verbose_name = _("Article Detail Widget")
         verbose_name_plural = _("Article Detail Widgets")
@@ -810,3 +828,56 @@ class ArticleDetailWidget(Widget):
             "prev": prev,
             "next": next,
         })
+
+class CardsWidget(Widget):
+    card_width = models.CharField(default="25%", max_length=32, verbose_name=_("Card Width"))
+    card_height = models.CharField(default="120px", max_length=32, verbose_name=_("Card Height"))
+    image_width = models.CharField(default="80px", max_length=32, verbose_name=_("Image Width"))
+    image_height = models.CharField(default="100px", max_length=32, verbose_name=_("Image Height"))
+    title_height = models.CharField(default="30px", max_length=32, verbose_name=_("Title Height"))
+
+    class Meta:
+        verbose_name = _("Cards Widget")
+        verbose_name_plural = _("Cards Widgets")
+
+    css = [
+        "django-power-cms/widgets/cards/css/cards.css",
+    ]
+
+    msms_category = _("Django Power Cms Default Widgets")
+    msms_priority = 3500
+
+    def render(self, request, global_context):
+        context = {}
+        context.update(global_context or {})
+        context.update({
+            "pk": self.pk,
+            "card_width": self.card_width,
+            "card_height": self.card_height,
+            "image_width": self.image_width,
+            "image_height": self.image_height,
+            "title_height": self.title_height,
+            "cards": self.items.all(),
+        })
+        return render_to_string("django-power-cms/widgets/cards.html", context)
+
+class CardsItem(models.Model):
+    widget = models.ForeignKey(CardsWidget, on_delete=models.CASCADE, related_name="items", verbose_name=_("Widget"))
+    image = models.ImageField(upload_to="card-images", verbose_name=_("Image"))
+    title = models.CharField(max_length=64, verbose_name=_("Title"))
+    description = models.CharField(max_length=128, verbose_name=_("Description"), null=True, blank=True)
+    order = models.IntegerField(default=0, verbose_name=_("Order"))
+    url_raw = models.CharField(max_length=128, null=True, blank=True, verbose_name=_("URL"))
+    open_url_in_new_window = models.BooleanField(default=False, verbose_name=_("Open URL In New Window"))
+
+    class Meta:
+        verbose_name = _("Card Item")
+        verbose_name_plural = _("Card Items")
+        ordering = ["order"]
+
+    def __str__(self):
+        return str(self.pk)
+
+    def url(self):
+        return get_url(self.url_raw)
+    url.short_description = _("URL")
